@@ -24,7 +24,7 @@ except ImportError:
 TEXT_ENDPOINT = "https://api.houndify.com/v1/text"
 VOICE_ENDPOINT = "https://api.houndify.com/v1/audio"
 TRANSCRIPTION_ENDPOINT = "https://api.houndify.com/v1/transcription"
-VERSION = "2.0.9"
+VERSION = "2.0.10"
 
 
 class HoundifySDKError(Exception):
@@ -91,14 +91,15 @@ class _BaseHoundClient(object):
 
       latitude and longitude are floats (not string)
       """
-      self.HoundRequestInfo["Latitude"] = latitude
-      self.HoundRequestInfo["Longitude"] = longitude
+      self.setHoundRequestInfo("Latitude", latitude)
+      self.setHoundRequestInfo("Longitude", longitude)
+
 
 
     def setConversationState(self, conversation_state):
-      self.HoundRequestInfo["ConversationState"] = conversation_state
+      self.setHoundRequestInfo("ConversationState", conversation_state)
       if "ConversationStateTime" in conversation_state:
-        self.HoundRequestInfo["ConversationStateTime"] = conversation_state["ConversationStateTime"]
+        self.setHoundRequestInfo("ConversationStateTime", conversation_state["ConversationStateTime"])
 
 
     def _generateHeaders(self, requestInfo):
@@ -134,6 +135,11 @@ class _BaseHoundClient(object):
       if not self.saveQuery:
         headers["Hound-Extra-Options"] = '{"DoNotSave": ["all"], "DoNotLabel": true}'
 
+      if self.hostname == "speech-a-41.pnp.melodis.com:14005":
+        # when using CI server authproxy will not check domain access
+        # so we have to fake enabling the Transcription domain
+        headers["EnabledDomains"] = "0000000000000000000000000000040000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000010"
+
       return headers, requestInfoString
 
 
@@ -145,7 +151,7 @@ class TextHoundClient(_BaseHoundClient):
     def __init__(self, clientID, clientKey, userID, requestInfo = dict(), endpoint = TEXT_ENDPOINT,
       proxyHost = None, proxyPort = None, proxyHeaders = None, timeout = None, saveQuery = True):
 
-      _BaseHoundClient.__init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery)
+      super().__init__(clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery)
       self.HoundRequestInfo.update(requestInfo)
 
 
@@ -197,6 +203,8 @@ class HoundListener(object):
       than 2 complete sentences. The first sentence can migrate to final
       """
       pass
+    def onEntityIdentification(self, entities, transcript):
+      pass
     def onPartialTranscriptTokens(self, transcript):
       """
       onPartialTranscriptTokens is fired when the server has a partial transcript.
@@ -235,14 +243,14 @@ class StreamingHoundClient(_BaseHoundClient):
       clientID and clientKey are "Client ID" and "Client Key"
       from the Houndify.com web site.
       """
-      _BaseHoundClient.__init__(self, clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery)
+      super().__init__(clientID, clientKey, userID, endpoint, proxyHost, proxyPort, proxyHeaders, timeout, saveQuery)
 
       self.sampleRate = sampleRate
       self.useSpeex = useSpeex
       self.speexFrameSize = int(2 * 0.02 * self.sampleRate) # 20ms 16-bit audio frame = (2 * 0.02 * sampleRate) bytes
       self.enableVAD = enableVAD
 
-      self.HoundRequestInfo["PartialTranscriptsDesired"] = True
+      self.setHoundRequestInfo("PartialTranscriptsDesired", True)
       self.HoundRequestInfo.update(requestInfo)
 
 
@@ -357,7 +365,13 @@ class StreamingHoundClient(_BaseHoundClient):
         except Exception as e:
           raise HoundifySDKError() from e
 
-        self.callbackTID.join(self.timeout)
+        try:
+          self.callbackTID.join(self.timeout)
+        except KeyboardInterrupt:
+          # If join fails to acquire a lock due to the KeyboardInterrupt
+          # it will release the lock, stop the thread and then raise
+          # the KeyboardInterrupt exception
+          pass
 
         if self.callbackTID.is_alive():
           # join timed out but thread is still running
@@ -451,6 +465,10 @@ class StreamingHoundClient(_BaseHoundClient):
                 listener.onFinalPartialTranscript(parsedMsg["FinalPartialTranscript"])
               except:
                 pass
+              try:
+                listener.onEntityIdentification(parsedMsg["EntityDetection"], parsedMsg["FinalPartialTranscriptTokens"])
+              except:
+                pass
               try:
                 listener.onPartialTranscriptTokens(parsedMsg["PartialTranscriptTokens"])
               except:
@@ -483,7 +501,7 @@ class StreamingHoundClient(_BaseHoundClient):
       genHeader += struct.pack("<H", 1)  #NumChannels
       genHeader += struct.pack("<L", sampleRate) #SampleRate
       genHeader += struct.pack("<L", 8 * sampleRate) #ByteRate
-      genHeader += struct.pack("<H", 2) #BlockAlign
+      genHeader += struct.pack("<H", 2) #BlockAlign (num of bytes per sample)
       genHeader += struct.pack("<H", 16) #BitsPerSample
       genHeader += "data".encode("UTF-8")
       genHeader += struct.pack("<L", 0) #Subchunk2Size - dummy
